{ callPackage
, system
, fenix
, naersk
, wasm-bindgen-cli
, stdenv
, fetchFromGitHub
, buildEnv
, pkg-config
, gettext
, wasm-pack
, binaryen
, openssl
, postgresql
}:

let
  wasm-bindgen-cli' = wasm-bindgen-cli.override {
    version = "0.2.89";
    hash = "sha256-IPxP68xtNSpwJjV2yNMeepAS0anzGl02hYlSTvPocz8=";
    cargoHash = "sha256-pBeQaG6i65uJrJptZQLuIaCb/WCQMhba1Z1OhYqA8Zc=";
  };
  rust = fenix.packages.${system}.complete.withComponents [
    "cargo"
    "rustc"
  ];
  naersk' = callPackage naersk {
    cargo = rust;
    rustc = rust;
  };
  rust-wasm = with fenix.packages.${system};
    combine [
      minimal.rustc
      minimal.cargo
      targets.wasm32-unknown-unknown.latest.rust-std
    ];
  naersk-wasm = callPackage naersk {
    cargo = rust-wasm;
    rustc = rust-wasm;
  };

  version = "0.7.2-2";

  src = stdenv.mkDerivation {
    pname = "plume-src";
    inherit version;
    src = fetchFromGitHub {
      owner = "Plume-org";
      repo = "Plume";
      rev = "304fb740d8ba3aaae64b3eb67ecfe476841b87c4";
      sha256 = "sha256-nMiVMR0arhv4bwx8b5FGawjQyiOXDhRZV8ERdBtHCYM=";
    };
    phases = [ "unpackPhase" "patchPhase" "installPhase" ];
    patches = [
      ./0001-cargo-update.patch
      ./0002-plume-front-fixup.patch
    ];
    installPhase = "cp -ar . $out";
  };

  plume = naersk'.buildPackage {
    pname = "plume";
    inherit src version;

    nativeBuildInputs = [
      pkg-config
      gettext
      wasm-bindgen-cli'
    ];
    buildInputs = [
      openssl
      postgresql
    ];
    overrideMain = oa: {
      installPhase = ''
        ${oa.installPhase}

        mkdir -p $out/share/plume
        cp -ar static $out/share/plume/
      '';
    };
  };

  plm = naersk'.buildPackage {
    pname = "plm";
    inherit version;
    root = src;

    nativeBuildInputs = [
      pkg-config
    ];
    buildInputs = [
      openssl
      postgresql
    ];
    cargoBuildOptions = x: x ++ [ "--package=plume-cli" ];
  };

  plume-front = naersk-wasm.buildPackage {
    pname = "plume-front";
    inherit version;
    root = src;
    nativeBuildInputs = [
      gettext
      wasm-pack
      wasm-bindgen-cli'
      binaryen
    ];
    CARGO_BUILD_TARGET = "wasm32-unknown-unknown";
    cargoBuildOptions = x:
      x ++ [
        "--package=plume-front"
      ];
    copyLibs = true;
    overrideMain = _: {
      buildPhase = ''
        WASM_PACK_CACHE=.wasm-pack-cache wasm-pack build --mode no-install --target web --release plume-front
      '';
      installPhase = ''
        mkdir -p $out/share/plume/static
        cp -a plume-front/pkg/*.{js,ts,wasm} $out/share/plume/static/
      '';
    };
  };
in
buildEnv {
  name = "plume-env";
  paths = [ plume plume-front plm ];
  passthru = { inherit plume plm; };
}
